@@ -2,17 +2,17 @@
    Copyright (C) 2006 g10 Code GmbH
 
    This file is part of libgpg-error.
- 
+
    libgpg-error is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public License
    as published by the Free Software Foundation; either version 2.1 of
    the License, or (at your option) any later version.
- 
+
    libgpg-error is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
- 
+
    You should have received a copy of the GNU Lesser General Public
    License along with libgpgme-error; if not, write to the Free
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
@@ -38,6 +38,9 @@ main (int argc, char *argv[])
   int save_errno;
   gpg_err_code_t ec;
 
+  (void)argc;
+  (void)argv;
+
   fp = fopen ("/does-not-exist/110761/nowhere.foo", "r");
   if (fp)
     {
